/**
 * 验证集合
 * author：苏航
 * date：2020-11-12
 */

/**
 * 企业统一社会信用代码
 * @param {*} code
 */
export const isEnterpriseCreditCode = (code) => {
  let reg = /^([0-9A-HJ-NPQRTUWXY]{2}\d{6}[0-9A-HJ-NPQRTUWXY]{10}|[1-9]\d{14})$/;
  let status = reg.test(code.toString());
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 验证身份证号
 * @param {String} code
 * @param {Boolean} verify
 */
import sIDCard from "s-id-card";
export const isIDCard = (code, verify) => {
  return sIDCard(code, verify);
};

/**
 * 邮箱
 * @param {*} code
 */
export const isEmail = (code) => {
  let reg = /^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+((.[a-zA-Z0-9_-]{2,3}){1,2})$/;
  let status = reg.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 电话号码
 * @param {*} code
 */
export const isTel = (code) => {
  let reg = /^(0\d{2,3}-\d{7,8})(-\d{1,4})?$/;
  let status = reg.test(code.toString());
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 手机号码
 * @param {*} code
 */
export const isPhone = (code) => {
  let reg = /^1[3|4|5|6|7|8|9][0-9]{9}$/;
  let status = reg.test(code.toString());
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 严格密码
 * 密码以字母开头，长度在6~18之间，只能包含字母、数字和下划线
 * @param {*} code
 */
export const isStrictPassword = (code) => {
  let reg = /^[a-zA-Z]\w{5,17}$/;
  let status = reg.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 检测密码强度
 * @param {*} str 
 */
export const checkPwd = (str) => {
  var Lv = 0;
  if (str.length < 6) {
      return Lv
  }
  if (/[0-9]/.test(str)) {
      Lv++
  }
  if (/[a-z]/.test(str)) {
      Lv++
  }
  if (/[A-Z]/.test(str)) {
      Lv++
  }
  if (/[.|-|_]/.test(str)) {
      Lv++
  }
  return Lv;
};

/**
 * 邮政编码
 * @param {*} code
 */
export const isPostal = (code) => {
  let reg = /[1-9]\d{5}(?!\d)/;
  let status = reg.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 车牌号码
 * @param {*} code
 */
export const isCarNumber = (code) => {
  const xreg = /^[京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼使领A-Z]{1}[A-Z]{1}(([0-9]{5}[DF]$)|([DF][A-HJ-NP-Z0-9][0-9]{4}$))/;
  const creg = /^[京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼使领A-Z]{1}[A-Z]{1}[A-HJ-NP-Z0-9]{4}[A-HJ-NP-Z0-9挂学警港澳]{1}$/;
  let status;
  if (code.length == 7) {
    status = creg.test(code);
  } else if (code.length == 8) {
    status = xreg.test(code);
  } else {
    status = false
  }
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};


/**
 * 车辆vin码 (车架号)
 * @param {*} code
 */
export const isVin = (code) => {
  let reg = /^[A-HJ-NPR-Z\d]{17}$/;
  let status = reg.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};



/**
 * 日期时间
 * @param {*} code
 */
export const isDate = (code) => {
  let status =
    /^(\d{4})-(\d{2})-(\d{2}) (\d{2})(?::\d{2}|:(\d{2}):(\d{2}))$/.test(code) ||
    /^(\d{4})-(\d{2})-(\d{2})$/.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 英文
 * @param {*} code
 */
export const isEnglish = (code) => {
  let reg = /^[a-zA-Z]+$/;
  let status = reg.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 中文
 * @param {*} code
 */
export const isChinese = (code) => {
  let reg = /^[\\u4E00-\\u9FA5]+$/;
  let status = reg.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 小写
 * @param {*} code
 */
export const isLower = (code) => {
  let reg = /^[a-z]+$/;
  let status = reg.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 大写
 * @param {*} code
 */
export const isUpper = (code) => {
  let reg = /^[A-Z]+$/;
  let status = reg.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 网址
 * @param {*} code
 */
export const isUrl = (code) => {
  let reg = /^http[s]?:\/\/.*/;
  let status = reg.test(code);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 字符串
 * @param {*} code
 */
export const isString = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "String";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 数字
 * @param {*} code
 */
export const isNumber = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "Number";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 布尔
 * @param {*} code
 */
export const isBoolean = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "Boolean";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 函数
 * @param {*} code
 */
export const isFunction = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "Function";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * null
 * @param {*} code
 */
export const isNull = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "Null";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * undefined
 * @param {*} code
 */
export const isUndefined = (code) => {
  let status =
    Object.prototype.toString.call(code).slice(8, -1) === "Undefined";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * Object
 * @param {*} code
 */
export const isObject = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "Object";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * Array
 * @param {*} code
 */
export const isArray = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "Array";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * Symbol函数
 * @param {*} code
 */
export const isSymbol = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "Symbol";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * Promise对象
 * @param {*} code
 */
export const isPromise = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "Promise";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * Set对象
 * @param {*} code
 */
export const isSet = (code) => {
  let status = Object.prototype.toString.call(code).slice(8, -1) === "Set";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    data: {
      code,
    },
    status,
  };
};

/**
 * 是否是微信浏览器
 * @param {*} code
 */
export const isWeiXin = () => {
  const ua = navigator.userAgent.toLowerCase();
  let status = ua.match(/microMessenger/i) == "micromessenger";
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    status,
  };
};

/**
 * 是否是移动端
 */
export const isDeviceMobile = () => {
  const ua = navigator.userAgent.toLowerCase();
  let status = /android|webos|iphone|ipod|balckberry/i.test(ua);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    status,
  };
};

/**
 * 是否是QQ浏览器
 */
export const isQQBrowser = () => {
  const ua = navigator.userAgent.toLowerCase();
  let status = !!ua.match(/mqqbrowser|qzone|qqbrowser|qbwebviewtype/i);
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    status,
  };
};

/**
 * 是否是爬虫
 */
export const isSpider = () => {
  const ua = navigator.userAgent.toLowerCase();
  let status = /adsbot|googlebot|bingbot|msnbot|yandexbot|baidubot|robot|careerbot|seznambot|bot|baiduspider|jikespider|symantecspider|scannerlwebcrawler|crawler|360spider|sosospider|sogou web sprider|sogou orion spider/.test(
    ua
  );
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    status,
  };
};

/**
 * 是否ios
 */
export const isIos = () => {
  const u = navigator.userAgent;
  let status = "";
  if (u.indexOf("Android") > -1 || u.indexOf("Linux") > -1) {
    //安卓手机
    status = false;
  } else if (u.indexOf("iPhone") > -1) {
    //苹果手机
    status = true;
  } else if (u.indexOf("iPad") > -1) {
    //iPad
    status = false;
  } else if (u.indexOf("Windows Phone") > -1) {
    //winphone手机
    status = false;
  } else {
    status = false;
  }

  return {
    msg: status ? "验证通过！" : "格式验证失败",
    status,
  };
};

/**
 * 是否为PC端
 */
export const isPC = () => {
  const userAgentInfo = navigator.userAgent;
  const Agents = [
    "Android",
    "iPhone",
    "SymbianOS",
    "Windows Phone",
    "iPad",
    "iPod",
  ];
  let status = true;
  for (var v = 0; v < Agents.length; v++) {
    if (userAgentInfo.indexOf(Agents[v]) > 0) {
      status = false;
      break;
    }
  }
  return {
    msg: status ? "验证通过！" : "格式验证失败",
    status,
  };
};
